@@ -35,3 +35,14 @@ class OrderedSet(list):
     def add(self, value):
         if value not in self:
             self.append(value)
+
+
+def is_flag(val):
+    """Guess if the value could be an on/off toggle"""
+    val = str(val)
+    return val.upper() in ('1', '0', 'F', 'T', 'TRUE', 'FALSE', 'ON', 'OFF')
+
+
+def flag_on(val):
+    """Return true if flag is on"""
+    return str(val).upper() in ('1', 'T', 'TRUE', 'ON')
